pub struct AsyncClient { /* private fields */ }

Implementations

Create new MQTT AsyncClient. Input: ConnectionSettings. Output: tuple

  • first element: AsyncClient,
  • second element: tuple
    • eventloop
    • incoming_event_broadcaster. This (eventloop, incoming_event_broadcaster) tuple should be used as an argument to the eventloop_monitor.

Publish to topic (no retaining of messages).

Subscribe to a topic.

Unsubscribe from a topic.

Get a broadcast channel receiver of the incoming messages. Intended to read the incoming messages from IoT Core.

Get the Rumqttc AsyncClient.

Get an eventloop handle.

Stops the eventloop.

Sends MQTT disconnect to the eventloop.